// Compiled by ClojureScript 1.9.229 {}
goog.provide('re_frame.events');
goog.require('cljs.core');
goog.require('re_frame.db');
goog.require('re_frame.utils');
goog.require('re_frame.interop');
goog.require('re_frame.registrar');
goog.require('re_frame.loggers');
goog.require('re_frame.interceptor');
goog.require('re_frame.trace');
re_frame.events.kind = new cljs.core.Keyword(null,"event","event",301435442);
if(cljs.core.truth_(re_frame.registrar.kinds.call(null,re_frame.events.kind))){
} else {
throw (new Error("Assert failed: (re-frame.registrar/kinds kind)"));
}
/**
 * `interceptors` might have nested collections, and contain nil elements.
 *   return a flat collection, with all nils removed.
 *   This function is 9/10 about giving good error messages
 */
re_frame.events.flatten_and_remove_nils = (function re_frame$events$flatten_and_remove_nils(id,interceptors){
var make_chain = (function (p1__14716_SHARP_){
return cljs.core.remove.call(null,cljs.core.nil_QMARK_,cljs.core.flatten.call(null,p1__14716_SHARP_));
});
if(!(re_frame.interop.debug_enabled_QMARK_)){
return make_chain.call(null,interceptors);
} else {
if(cljs.core.coll_QMARK_.call(null,interceptors)){
} else {
re_frame.loggers.console.call(null,new cljs.core.Keyword(null,"error","error",-978969032),[cljs.core.str("re-frame: when registering "),cljs.core.str(id),cljs.core.str(", expected a collection of interceptors, got:")].join(''),interceptors);
}

var chain = make_chain.call(null,interceptors);
if(cljs.core.empty_QMARK_.call(null,chain)){
re_frame.loggers.console.call(null,new cljs.core.Keyword(null,"error","error",-978969032),[cljs.core.str("re-frame: when registering"),cljs.core.str(id),cljs.core.str(", given an empty interceptor chain")].join(''));
} else {
}

var temp__4657__auto___14717 = cljs.core.first.call(null,cljs.core.remove.call(null,re_frame.interceptor.interceptor_QMARK_,chain));
if(cljs.core.truth_(temp__4657__auto___14717)){
var not_i_14718 = temp__4657__auto___14717;
if(cljs.core.fn_QMARK_.call(null,not_i_14718)){
re_frame.loggers.console.call(null,new cljs.core.Keyword(null,"error","error",-978969032),[cljs.core.str("re-frame: when registering "),cljs.core.str(id),cljs.core.str(", got a function instead of an interceptor. Did you provide old style middleware by mistake? Got:")].join(''),not_i_14718);
} else {
re_frame.loggers.console.call(null,new cljs.core.Keyword(null,"error","error",-978969032),[cljs.core.str("re-frame: when registering "),cljs.core.str(id),cljs.core.str(", expected interceptors, but got:")].join(''),not_i_14718);
}
} else {
}

return chain;
}
});
/**
 * Associate the given event `id` with the given collection of `interceptors`.
 * 
 * `interceptors` may contain nested collections and there may be nils
 * at any level,so process this structure into a simple, nil-less vector
 * before registration.
 * 
 * An `event handler` will likely be at the end of the chain (wrapped in an interceptor).
 */
re_frame.events.register = (function re_frame$events$register(id,interceptors){
return re_frame.registrar.register_handler.call(null,re_frame.events.kind,id,re_frame.events.flatten_and_remove_nils.call(null,id,interceptors));
});
re_frame.events._STAR_handling_STAR_ = null;
/**
 * Given an event vector, look up the associated intercepter chain, and execute it.
 */
re_frame.events.handle = (function re_frame$events$handle(event_v){
var event_id = re_frame.utils.first_in_vector.call(null,event_v);
var temp__4655__auto__ = re_frame.registrar.get_handler.call(null,re_frame.events.kind,event_id,true);
if(cljs.core.truth_(temp__4655__auto__)){
var interceptors = temp__4655__auto__;
if(cljs.core.truth_(re_frame.events._STAR_handling_STAR_)){
return re_frame.loggers.console.call(null,new cljs.core.Keyword(null,"error","error",-978969032),[cljs.core.str("re-frame: while handling \""),cljs.core.str(re_frame.events._STAR_handling_STAR_),cljs.core.str("\", dispatch-sync was called for \""),cljs.core.str(event_v),cljs.core.str("\". You can't call dispatch-sync within an event handler.")].join(''));
} else {
var _STAR_handling_STAR_14733 = re_frame.events._STAR_handling_STAR_;
re_frame.events._STAR_handling_STAR_ = event_v;

try{if(re_frame.trace.is_trace_enabled_QMARK_.call(null)){
var _STAR_current_trace_STAR_14734 = re_frame.trace._STAR_current_trace_STAR_;
re_frame.trace._STAR_current_trace_STAR_ = re_frame.trace.start_trace.call(null,new cljs.core.PersistentArrayMap(null, 3, [new cljs.core.Keyword(null,"operation","operation",-1267664310),event_id,new cljs.core.Keyword(null,"op-type","op-type",-1636141668),re_frame.events.kind,new cljs.core.Keyword(null,"tags","tags",1771418977),new cljs.core.PersistentArrayMap(null, 1, [new cljs.core.Keyword(null,"event","event",301435442),event_v], null)], null));

try{try{return re_frame.interceptor.execute.call(null,event_v,interceptors);
}finally {if(re_frame.trace.is_trace_enabled_QMARK_.call(null)){
var end__14651__auto___14747 = re_frame.interop.now.call(null);
var duration__14652__auto___14748 = (end__14651__auto___14747 - new cljs.core.Keyword(null,"start","start",-355208981).cljs$core$IFn$_invoke$arity$1(re_frame.trace._STAR_current_trace_STAR_));
var seq__14735_14749 = cljs.core.seq.call(null,cljs.core.deref.call(null,re_frame.trace.trace_cbs));
var chunk__14736_14750 = null;
var count__14737_14751 = (0);
var i__14738_14752 = (0);
while(true){
if((i__14738_14752 < count__14737_14751)){
var vec__14739_14753 = cljs.core._nth.call(null,chunk__14736_14750,i__14738_14752);
var k__14653__auto___14754 = cljs.core.nth.call(null,vec__14739_14753,(0),null);
var cb__14654__auto___14755 = cljs.core.nth.call(null,vec__14739_14753,(1),null);
try{cb__14654__auto___14755.call(null,new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [cljs.core.assoc.call(null,re_frame.trace._STAR_current_trace_STAR_,new cljs.core.Keyword(null,"duration","duration",1444101068),duration__14652__auto___14748,new cljs.core.Keyword(null,"end","end",-268185958),re_frame.interop.now.call(null))], null));
}catch (e14742){if((e14742 instanceof java.lang.Exception)){
var e__14655__auto___14756 = e14742;
re_frame.loggers.console.call(null,new cljs.core.Keyword(null,"error","error",-978969032),"Error thrown from trace cb",k__14653__auto___14754,"while storing",re_frame.trace._STAR_current_trace_STAR_,e__14655__auto___14756);
} else {
throw e14742;

}
}
var G__14757 = seq__14735_14749;
var G__14758 = chunk__14736_14750;
var G__14759 = count__14737_14751;
var G__14760 = (i__14738_14752 + (1));
seq__14735_14749 = G__14757;
chunk__14736_14750 = G__14758;
count__14737_14751 = G__14759;
i__14738_14752 = G__14760;
continue;
} else {
var temp__4657__auto___14761 = cljs.core.seq.call(null,seq__14735_14749);
if(temp__4657__auto___14761){
var seq__14735_14762__$1 = temp__4657__auto___14761;
if(cljs.core.chunked_seq_QMARK_.call(null,seq__14735_14762__$1)){
var c__7220__auto___14763 = cljs.core.chunk_first.call(null,seq__14735_14762__$1);
var G__14764 = cljs.core.chunk_rest.call(null,seq__14735_14762__$1);
var G__14765 = c__7220__auto___14763;
var G__14766 = cljs.core.count.call(null,c__7220__auto___14763);
var G__14767 = (0);
seq__14735_14749 = G__14764;
chunk__14736_14750 = G__14765;
count__14737_14751 = G__14766;
i__14738_14752 = G__14767;
continue;
} else {
var vec__14743_14768 = cljs.core.first.call(null,seq__14735_14762__$1);
var k__14653__auto___14769 = cljs.core.nth.call(null,vec__14743_14768,(0),null);
var cb__14654__auto___14770 = cljs.core.nth.call(null,vec__14743_14768,(1),null);
try{cb__14654__auto___14770.call(null,new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [cljs.core.assoc.call(null,re_frame.trace._STAR_current_trace_STAR_,new cljs.core.Keyword(null,"duration","duration",1444101068),duration__14652__auto___14748,new cljs.core.Keyword(null,"end","end",-268185958),re_frame.interop.now.call(null))], null));
}catch (e14746){if((e14746 instanceof java.lang.Exception)){
var e__14655__auto___14771 = e14746;
re_frame.loggers.console.call(null,new cljs.core.Keyword(null,"error","error",-978969032),"Error thrown from trace cb",k__14653__auto___14769,"while storing",re_frame.trace._STAR_current_trace_STAR_,e__14655__auto___14771);
} else {
throw e14746;

}
}
var G__14772 = cljs.core.next.call(null,seq__14735_14762__$1);
var G__14773 = null;
var G__14774 = (0);
var G__14775 = (0);
seq__14735_14749 = G__14772;
chunk__14736_14750 = G__14773;
count__14737_14751 = G__14774;
i__14738_14752 = G__14775;
continue;
}
} else {
}
}
break;
}
} else {
}
}}finally {re_frame.trace._STAR_current_trace_STAR_ = _STAR_current_trace_STAR_14734;
}} else {
return re_frame.interceptor.execute.call(null,event_v,interceptors);
}
}finally {re_frame.events._STAR_handling_STAR_ = _STAR_handling_STAR_14733;
}}
} else {
return null;
}
});

//# sourceMappingURL=events.js.map?rel=1499873949736